from .common import *

LANGUAGE_CODE = 'nb'
